@@ -5,7 +5,8 @@ function make_conda_root_env { # creates the root conda env if not present yet
     echo -e "\x1b[1mInstalling micromamba.\x1b[0m"
     echo "Please confirm all question unless you know what you are doing."
     "${SHELL}" <(curl -L micro.mamba.pm/install.sh)
-    call . "$HOME/.$(basename $SHELL)rc"
+    . "$HOME/.$(basename $SHELL)rc"
+    eval "$(micromamba shell hook --shell "bash")"
     call micromamba activate
     call eval micromamba install --yes $root_tools ${conda_root_tools:-}
     call micromamba info
@@ -14,8 +15,10 @@ function make_conda_root_env { # creates the root conda env if not present yet
 
 function make_conda_py_env { # creates the venv for the project and poetry installs
     # main conda bin is in path
+    set -x
     local n="${PROJECT}_py${pyver}"
     local p="$(conda_root)/envs/$n"
+    eval "$(micromamba shell hook --shell "bash")"
     call micromamba activate
     test -e "$p" || {
         echo "Installing $p (with tools: $conda_project_tools)"
