@@ -29,7 +29,7 @@ def build_chain_from_list(processors):
     ctx = {'last': 'beginning', 'nr': 0}
 
     def processor(p, ctx=ctx):
-        if not isinstance(p, (basestring, dict)):
+        if not isinstance(p, (str, dict)):
             # already done:
             return p
 
@@ -148,7 +148,7 @@ def preprocess_dict_config(C):
                 [
                     loggers[l]['handlers'].append(h)
                     for l in loggers
-                    if re.match(match, l) and not h in loggers[l]['handlers']
+                    if re.match(match, l) and h not in loggers[l]['handlers']
                 ]
 
             [add_handler(C['loggers'], match, hdl) for match, hdl in cfg.items()]
